@@ -1,20 +1,6 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Code generation for locals dict handling.
 
 These are variable handling for classes and partially also Python2 exec
@@ -196,7 +182,6 @@ def generateLocalsDictVariableRefOrFallbackCode(to_name, expression, emit, conte
     with withObjectCodeTemporaryAssignment(
         to_name, "locals_lookup_value", expression, emit, context
     ) as value_name:
-
         generateExpressionCode(
             to_name=value_name,
             expression=expression.subnode_fallback,
@@ -260,7 +245,6 @@ def generateLocalsDictVariableRefCode(to_name, expression, emit, context):
     with withObjectCodeTemporaryAssignment(
         to_name, "locals_lookup_value", expression, emit, context
     ) as value_name:
-
         emit(
             template
             % {
@@ -272,7 +256,8 @@ def generateLocalsDictVariableRefCode(to_name, expression, emit, context):
 
         getNameReferenceErrorCode(
             variable_name=variable_name,
-            condition="%s == NULL && CHECK_AND_CLEAR_KEY_ERROR_OCCURRED()" % value_name,
+            condition="%s == NULL && CHECK_AND_CLEAR_KEY_ERROR_OCCURRED(tstate)"
+            % value_name,
             emit=emit,
             context=context,
         )
@@ -295,7 +280,7 @@ def generateLocalsDictVariableCheckCode(to_name, expression, emit, context):
     if is_dict:
         to_name.getCType().emitAssignmentCodeFromBoolCondition(
             to_name=to_name,
-            condition="DICT_HAS_ITEM(%(locals_dict)s, %(var_name)s) == 1"
+            condition="DICT_HAS_ITEM(tstate, %(locals_dict)s, %(var_name)s) == 1"
             % {
                 "locals_dict": locals_declaration,
                 "var_name": context.getConstantCode(constant=variable_name),
@@ -306,7 +291,7 @@ def generateLocalsDictVariableCheckCode(to_name, expression, emit, context):
         tmp_name = context.getIntResName()
 
         template = """\
-%(tmp_name)s = MAPPING_HAS_ITEM(%(locals_dict)s, %(var_name)s);
+%(tmp_name)s = MAPPING_HAS_ITEM(tstate, %(locals_dict)s, %(var_name)s);
 """
 
         emit(
@@ -328,3 +313,19 @@ def generateLocalsDictVariableCheckCode(to_name, expression, emit, context):
         to_name.getCType().emitAssignmentCodeFromBoolCondition(
             to_name=to_name, condition="%s == 1" % tmp_name, emit=emit
         )
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
