@@ -1,20 +1,6 @@
-#     Copyright 2023, Batakrishna Sahu, mailto:<Batakrishna.Sahu@suiit.ac.in>
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2024, Batakrishna Sahu, mailto:<Batakrishna.Sahu@suiit.ac.in> find license text at end of file
+
+
 """ Node for Iteration Handles.
 
 """
@@ -22,12 +8,15 @@
 import math
 from abc import abstractmethod
 
-from nuitka.__past__ import getMetaClassBase, xrange
+from nuitka.__past__ import xrange
+from nuitka.utils.SlotMetaClasses import getMetaClassBase
 
 
-class IterationHandleBase(getMetaClassBase("IterationHandle")):
+class IterationHandleBase(getMetaClassBase("IterationHandle", require_slots=True)):
     """Base class for Iteration Handles."""
 
+    __slots__ = ()
+
     @abstractmethod
     def getNextValueExpression(self):
         """Abstract method to get next iteration value."""
@@ -93,6 +82,11 @@ class ConstantIterationHandleBase(IterationHandleBase):
         Returns the boolean value of the next handle
     """
 
+    __slots__ = (
+        "constant_node",
+        "iter",
+    )
+
     def __init__(self, constant_node):
         assert constant_node.isIterableConstant()
 
@@ -142,8 +136,7 @@ class ConstantIndexableIterationHandle(ConstantIterationHandleBase):
         Sequential access of the constants
     """
 
-    def __init__(self, constant_node):
-        ConstantIterationHandleBase.__init__(self, constant_node)
+    __slots__ = ()
 
     def getIterationValueWithIndex(self, value_index):
         """Tries to return constant value at the given index.
@@ -165,50 +158,49 @@ class ConstantIndexableIterationHandle(ConstantIterationHandleBase):
 
 
 class ConstantTupleIterationHandle(ConstantIndexableIterationHandle):
-    pass
+    __slots__ = ()
 
 
 class ConstantListIterationHandle(ConstantIndexableIterationHandle):
-    pass
+    __slots__ = ()
 
 
 class ConstantStrIterationHandle(ConstantIndexableIterationHandle):
-    pass
+    __slots__ = ()
 
 
 class ConstantUnicodeIterationHandle(ConstantIndexableIterationHandle):
-    pass
+    __slots__ = ()
 
 
 class ConstantBytesIterationHandle(ConstantIndexableIterationHandle):
-    pass
+    __slots__ = ()
 
 
 class ConstantBytearrayIterationHandle(ConstantIndexableIterationHandle):
-    pass
+    __slots__ = ()
 
 
 class ConstantRangeIterationHandle(ConstantIndexableIterationHandle):
-    pass
+    __slots__ = ()
 
 
 class ConstantSetAndDictIterationHandleBase(ConstantIterationHandleBase):
     """Class for the set and dictionary constants."""
 
-    def __init__(self, constant_node):
-        ConstantIterationHandleBase.__init__(self, constant_node)
+    __slots__ = ()
 
 
 class ConstantSetIterationHandle(ConstantSetAndDictIterationHandleBase):
-    pass
+    __slots__ = ()
 
 
 class ConstantFrozensetIterationHandle(ConstantSetAndDictIterationHandleBase):
-    pass
+    __slots__ = ()
 
 
 class ConstantDictIterationHandle(ConstantSetAndDictIterationHandleBase):
-    pass
+    __slots__ = ()
 
 
 class ListAndTupleContainerMakingIterationHandle(IterationHandleBase):
@@ -232,6 +224,8 @@ class ListAndTupleContainerMakingIterationHandle(IterationHandleBase):
         Sequential access of the expression
     """
 
+    __slots__ = ("elements", "iter")
+
     def __init__(self, elements):
         self.elements = elements
         self.iter = iter(self.elements)
@@ -272,11 +266,13 @@ class RangeIterationHandleBase(IterationHandleBase):
     high : int
         Optional. An integer number specifying at which position to end.
     step : int
-        Optional. An integer number specifying the incrementation. Default is 1
+        Optional. An integer number specifying the increment. Default is 1
     """
 
     step = 1
 
+    __slots__ = ("low", "iter", "source_ref")
+
     def __init__(self, low_value, range_value, source_ref):
         self.low = low_value
         self.iter = iter(range_value)
@@ -332,6 +328,8 @@ class RangeIterationHandleBase(IterationHandleBase):
 class IterationHandleRange1(RangeIterationHandleBase):
     """Iteration handle for range(low,)"""
 
+    __slots__ = ()
+
     def __init__(self, low_value, source_ref):
         RangeIterationHandleBase.__init__(
             self, low_value, xrange(low_value), source_ref
@@ -348,6 +346,8 @@ class IterationHandleRange1(RangeIterationHandleBase):
 class IterationHandleRange2(RangeIterationHandleBase):
     """Iteration handle for ranges(low, high)"""
 
+    __slots__ = ("high",)
+
     def __init__(self, low_value, high_value, source_ref):
         RangeIterationHandleBase.__init__(
             self, low_value, xrange(low_value, high_value), source_ref
@@ -362,6 +362,11 @@ class IterationHandleRange2(RangeIterationHandleBase):
 class IterationHandleRange3(RangeIterationHandleBase):
     """Iteration handle for ranges(low, high, step)"""
 
+    __slots__ = (
+        "high",
+        "step",
+    )
+
     def __init__(self, low_value, high_value, step_value, source_ref):
         RangeIterationHandleBase.__init__(
             self, low_value, xrange(low_value, high_value, step_value), source_ref
@@ -384,3 +389,19 @@ class IterationHandleRange3(RangeIterationHandleBase):
         assert estimate >= 0
 
         return int(estimate)
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
